@@ -64,26 +64,26 @@ var NAVTREEINDEX =
 "annotated.html",
 "globals_defs_p.html",
 "globals_k.html",
-"group__pw__context.html#gace5ee0a357a22a1dd86e3398956a621e",
-"group__pw__impl__link.html#ga3baed016411a9a3d0f7407c3a9144b39",
-"group__pw__link.html#gaa90bcda1ac9edbb5f2c92703f1e38d84",
-"group__pw__port.html#gac5541bb77b42b3e6d41d4ee9b4c06b6f",
-"group__pw__session__manager.html#gaa17ffb9525d1063cdff54c7dcc5cda2d",
-"group__spa__ansi.html#ga8b943fd646e64cbd0fa60484a0900d94",
-"group__spa__device.html#gab68858d85274969e6f2502e95547f429",
-"group__spa__log.html#ga24e95908846b410227578abfc63b0bf0",
-"group__spa__node.html#gadcbf11755fca00d5a654a79ee80fdb81",
-"group__spa__param.html#gadf20a282139c86a669212c8d36262ad6",
-"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81a518d2c1ae61f251ca0b9adf16fac6325",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaaea330d28cd1cc792d707a49b60ca2ba5",
-"group__spa__pod.html#ga765ef8a7efa487db110ec67c998ff2ea",
-"group__spa__types.html#ga4aae17a0b82f8be6d450a8fa3a102225",
-"page_midi.html#autotoc_md25",
-"structpw__client__session.html",
-"structpw__impl__port.html",
-"structpw__stream__events.html#a0cdc45fef5f2458a0fd11a6e9ef1f6fb",
-"structspa__i18n__methods.html#a7ceb5c3a7165fbfb3ee340574881d675",
-"structspa__pod__builder__state.html#ad4d8cb79bdf194c752fc697eb7d63341"
+"group__pw__context.html#gaac1368cbbe2e1a00b066c552c86ba3a8",
+"group__pw__impl__link.html#ga1d14d440f9b78ff302371e49fca32a36",
+"group__pw__link.html#ga72d8e03483fd111c9a9eb87aac3897a2",
+"group__pw__port.html#ga866d33374688faec738124490db2877e",
+"group__pw__session__manager.html#ga9ce6b085d6110a166e03135e3977c7f2",
+"group__spa__ansi.html#ga678d0b293b16e0d6a1fe0acef4915d58",
+"group__spa__device.html#ga9f19955c5b6a77028eb697a130a5f22e",
+"group__spa__log.html#ga05409b56c8a7c7248cc371f5a1e965b6",
+"group__spa__node.html#gad77bdd23db7c222a58280dcda2ed63ff",
+"group__spa__param.html#gad7758d1c91573ef57ebf61ac113bb43e",
+"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81a3e57ce2f67cc65627be17e20186b3df5",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaab5754c80b7702b8b2283db1f3ec185bf",
+"group__spa__pod.html#ga697129f8c015770ec03468adf9127705",
+"group__spa__thread.html#ga7c5acfdece976cd3f7b12dee4ddb3e41",
+"page_man_pw_jack_1.html",
+"structpw__client__node__events.html#ab1aba9806056fc945c2328f1cc128f6e",
+"structpw__impl__node__events.html#a4364b27231c433313991f473948e5e3f",
+"structpw__session__methods.html#a6720d4c6b23022393bc945c656ba5fe0",
+"structspa__handle__factory.html#aa48d0b857861f618011a9f4a89435484",
+"structspa__pod__bool.html#ace69d7dd77f754dc466e24e0598b865c"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
