@@ -1,5 +1,11 @@
 var NAVTREEINDEX10 =
 {
+"group__spa__log.html#ga05409b56c8a7c7248cc371f5a1e965b6":[10,8,9,3,16],
+"group__spa__log.html#ga08076f4c659566e0c3f1a8dee549b63d":[10,8,9,3,38],
+"group__spa__log.html#ga0b5b333c2b7fbc5470f7ec68944e20a1":[10,8,9,3,8],
+"group__spa__log.html#ga0f6523b51087c252b5ccf1b68bdce51d":[10,8,9,3,42],
+"group__spa__log.html#ga142802024be8a40bef345806d498d6b6":[10,8,9,3,25],
+"group__spa__log.html#ga16d4dbdafbf101743358d848406dbc14":[10,8,9,3,35],
 "group__spa__log.html#ga24e95908846b410227578abfc63b0bf0":[10,8,9,3,30],
 "group__spa__log.html#ga2a153ee3bd5ce9737fc4f7b6e78084f1":[10,8,9,3,43],
 "group__spa__log.html#ga2c68f365acc6805c88aa81ec720f4ca8":[10,8,9,3,31],
@@ -243,11 +249,5 @@ var NAVTREEINDEX10 =
 "group__spa__node.html#gad3d0d597b9c901a69e6b9fd647594c76":[10,8,6,111],
 "group__spa__node.html#gad62e2c5acaf8499bd307e16477ba1a97":[10,8,6,124],
 "group__spa__node.html#gad6554ded385c335b205111415b697db3":[10,8,6,27],
-"group__spa__node.html#gad744ab5bf6a56885dd8f283fd28b911c":[10,8,6,146],
-"group__spa__node.html#gad77bdd23db7c222a58280dcda2ed63ff":[10,8,6,62],
-"group__spa__node.html#gad819a9a2cb2c5b53ae744c48568772f1":[10,8,6,95],
-"group__spa__node.html#gad8a56491e1cb021d5a6f168a538a6ae5":[10,8,6,127],
-"group__spa__node.html#gada8de413ca18ab054c45f9aba3503af9":[10,8,6,87],
-"group__spa__node.html#gadb0d4466139648f1937c0ea07b150e19":[10,8,6,105],
-"group__spa__node.html#gadcb55c17c2f80d36f159bc763fd309e7":[10,8,6,51]
+"group__spa__node.html#gad744ab5bf6a56885dd8f283fd28b911c":[10,8,6,146]
 };
