@@ -1,5 +1,20 @@
 var NAVTREEINDEX21 =
 {
+"structspa__handle__factory.html#aa48d0b857861f618011a9f4a89435484":[10,8,9,5,4,2],
+"structspa__handle__factory.html#ad9e9ca49d03aed627c1c1ac5db5266d7":[10,8,9,5,4,3],
+"structspa__hook.html":[10,8,8,4,2],
+"structspa__hook.html#a439678f47d124fd66beec84984c9de75":[10,8,8,4,2,2],
+"structspa__hook.html#a87415e24dddc82ef6048c3572a88cfd7":[10,8,8,4,2,1],
+"structspa__hook.html#aa750440084804e95fb24f95de3eb5d54":[10,8,8,4,2,0],
+"structspa__hook.html#ac503424bd37fd0f8b8e6ba5bb248d8a5":[10,8,8,4,2,3],
+"structspa__hook__list.html":[10,8,8,4,1],
+"structspa__hook__list.html#a6f6f1ee63f0ded77544da4fa3e35a732":[10,8,8,4,1,0],
+"structspa__i18n.html":[10,8,9,2,1],
+"structspa__i18n.html#a4ca10c865fe33ffff4fd9abb9265c0f8":[10,8,9,2,1,0],
+"structspa__i18n__methods.html":[10,8,9,2,2],
+"structspa__i18n__methods.html#a3aa971d572e886ab027a897a288f767b":[10,8,9,2,2,0],
+"structspa__i18n__methods.html#a7ceb5c3a7165fbfb3ee340574881d675":[10,8,9,2,2,1],
+"structspa__i18n__methods.html#a884391486c3277069fb8ee2f9d754234":[10,8,9,2,2,2],
 "structspa__interface.html":[10,8,8,5,2],
 "structspa__interface.html#a2572eec5caf615f77e143013373cdcdf":[10,8,8,5,2,1],
 "structspa__interface.html#a99da3754855d6dd1430d21ed97fa0bfb":[10,8,8,5,2,0],
@@ -234,20 +249,5 @@ var NAVTREEINDEX21 =
 "structspa__pod__bitmap.html#ad45678422944ed0fd6a3b82b976497dc":[10,8,0,30,0],
 "structspa__pod__bool.html":[10,8,0,20],
 "structspa__pod__bool.html#a0813dfc89b4ac463bbbe527dd64723a0":[10,8,0,20,2],
-"structspa__pod__bool.html#aa9db4ceb398b4e0b3ffba65b08c38c4d":[10,8,0,20,1],
-"structspa__pod__bool.html#ace69d7dd77f754dc466e24e0598b865c":[10,8,0,20,0],
-"structspa__pod__builder.html":[10,8,0,11],
-"structspa__pod__builder.html#a0cbaecf9bb1eaa9091928f88f52f1dec":[10,8,0,11,2],
-"structspa__pod__builder.html#a10358b3530a605742fbd6488ec1acffd":[10,8,0,11,4],
-"structspa__pod__builder.html#a4a8ea2b371e6be4e67bf6ce0b64c5ab2":[10,8,0,11,0],
-"structspa__pod__builder.html#a701f8e524b951931ce8e390b96c75db9":[10,8,0,11,3],
-"structspa__pod__builder.html#a9c1ccf4a2a2d89854665f96764835bbf":[10,8,0,11,1],
-"structspa__pod__builder__callbacks.html":[10,8,0,10],
-"structspa__pod__builder__callbacks.html#a8acfb9e8c57e0c3ac2d3dac4a4f37aa6":[10,8,0,10,1],
-"structspa__pod__builder__callbacks.html#ad6d4638170f1441ba8c786ea174df911":[10,8,0,10,0],
-"structspa__pod__builder__state.html":[10,8,0,9],
-"structspa__pod__builder__state.html#a9406fb7fd6f0ea3cc9e99c9be6d76661":[10,8,0,9,1],
-"structspa__pod__builder__state.html#ac64c9a0aad0f5630c44c86e97561ffae":[10,8,0,9,0],
-"structspa__pod__builder__state.html#ad4d8cb79bdf194c752fc697eb7d63341":[10,8,0,9,2],
-"structspa__pod__bytes.html":[10,8,0,27]
+"structspa__pod__bool.html#aa9db4ceb398b4e0b3ffba65b08c38c4d":[10,8,0,20,1]
 };
