@@ -1,5 +1,10 @@
 var NAVTREEINDEX9 =
 {
+"group__spa__device.html#ga9f19955c5b6a77028eb697a130a5f22e":[10,8,4,47],
+"group__spa__device.html#ga9fc516e68fefb9e3c7f08a5fa4ac8242":[10,8,4,22],
+"group__spa__device.html#gaa6141368f70a58863efc5494673903ba":[10,8,4,33],
+"group__spa__device.html#gaa8e69a2fae59e8d6d1d1da5f0660cbc3":[10,8,4,13],
+"group__spa__device.html#gab347a871f54232e2f8362c60fd893128":[10,8,4,21],
 "group__spa__device.html#gab68858d85274969e6f2502e95547f429":[10,8,4,51],
 "group__spa__device.html#gab7ccc98f93f0269396bcbcd3efd1fdb8":[10,8,4,18],
 "group__spa__device.html#gabcb2230b6ab2020ceef73fad9e1fd7dc":[10,8,4,70],
@@ -219,17 +224,18 @@ var NAVTREEINDEX9 =
 "group__spa__keys.html#gaf4b04c9ed82a9d207ec02cea4d82de10":[10,8,8,7,27],
 "group__spa__list.html":[10,8,8,3],
 "group__spa__list.html#ga108cc4dbe3573f71ac8fa0e6d54b8dac":[10,8,8,3,9],
-"group__spa__list.html#ga15db195a9509817eb07df421de1b1ffc":[10,8,8,3,24],
+"group__spa__list.html#ga15db195a9509817eb07df421de1b1ffc":[10,8,8,3,25],
 "group__spa__list.html#ga1cc2697f03626118318c1506bed70767":[10,8,8,3,8],
 "group__spa__list.html#ga26b91db2741857b5402dbc6ec0cd7857":[10,8,8,3,22],
 "group__spa__list.html#ga2b8d65766f4dfe2a009073a3ed3a8edb":[10,8,8,3,15],
+"group__spa__list.html#ga32ec10b38637983ef5347a13e51d6612":[10,8,8,3,24],
 "group__spa__list.html#ga45afc4b42dfaa194a4675532338fc621":[10,8,8,3,12],
 "group__spa__list.html#ga49f1884c56d222f6e7d68e437728366a":[10,8,8,3,13],
 "group__spa__list.html#ga587a1750ebac2e8f980228db27b44e0f":[10,8,8,3,10],
 "group__spa__list.html#ga60b0fbabb70671c71d40e5443f6489d8":[10,8,8,3,11],
 "group__spa__list.html#ga731aaed174d63ae6cc01cddde266ed73":[10,8,8,3,23],
 "group__spa__list.html#ga75add8c86fa73d438fdfc3568062bb45":[10,8,8,3,21],
-"group__spa__list.html#ga7c4f3862b62ea26df079936f5ebfdacc":[10,8,8,3,26],
+"group__spa__list.html#ga7c4f3862b62ea26df079936f5ebfdacc":[10,8,8,3,27],
 "group__spa__list.html#ga94381f31e216abb3a54a9c8866318818":[10,8,8,3,4],
 "group__spa__list.html#ga964734871c9792e189ce23a08b74c4d0":[10,8,8,3,17],
 "group__spa__list.html#gaadec436f232586998917c75efeac05ab":[10,8,8,3,20],
@@ -242,12 +248,6 @@ var NAVTREEINDEX9 =
 "group__spa__list.html#gadea44c074f21f2a8c15825e526110bf0":[10,8,8,3,18],
 "group__spa__list.html#gae1826e761b00fde76907589f66cf74a9":[10,8,8,3,19],
 "group__spa__list.html#gaf76607bd5d48aa7b41d693260a19b68e":[10,8,8,3,5],
-"group__spa__list.html#gafbca4263c0f4f6afba58f226bfb99198":[10,8,8,3,25],
-"group__spa__log.html":[10,8,9,3],
-"group__spa__log.html#ga05409b56c8a7c7248cc371f5a1e965b6":[10,8,9,3,16],
-"group__spa__log.html#ga08076f4c659566e0c3f1a8dee549b63d":[10,8,9,3,38],
-"group__spa__log.html#ga0b5b333c2b7fbc5470f7ec68944e20a1":[10,8,9,3,8],
-"group__spa__log.html#ga0f6523b51087c252b5ccf1b68bdce51d":[10,8,9,3,42],
-"group__spa__log.html#ga142802024be8a40bef345806d498d6b6":[10,8,9,3,25],
-"group__spa__log.html#ga16d4dbdafbf101743358d848406dbc14":[10,8,9,3,35]
+"group__spa__list.html#gafbca4263c0f4f6afba58f226bfb99198":[10,8,8,3,26],
+"group__spa__log.html":[10,8,9,3]
 };
